@@ -60,6 +60,7 @@ typedef struct
 #define DEFAULT_COMMAND_GENERATE "autogen.sh"
 #define DEFAULT_COMMAND_CLEAN "make clean"
 #define DEFAULT_COMMAND_DISTCLEAN "make distclean"
+#define DEFAULT_COMMAND_CHECK "make check"
 #define DEFAULT_COMMAND_AUTORECONF "autoreconf -i --force"
 
 #define CHOOSE_COMMAND(plugin,command) \
@@ -443,7 +444,7 @@ build_execute_command (BasicAutotoolsPlugin* bplugin, BuildProgram *prog,
 	BuildContext *context;
 	gboolean ok;
 
-	context = build_get_context (bplugin, prog->work_dir, with_view, FALSE);
+	context = build_get_context (bplugin, prog->work_dir, with_view);
 
 	build_set_command_in_context (context, prog);
 	ok = build_execute_command_in_context (context, err);
@@ -462,11 +463,11 @@ build_execute_command (BasicAutotoolsPlugin* bplugin, BuildProgram *prog,
 
 static BuildContext*
 build_save_and_execute_command (BasicAutotoolsPlugin* bplugin, BuildProgram *prog,
-								gboolean with_view, gboolean check_password, GError **err)
+								gboolean with_view, GError **err)
 {
 	BuildContext *context;
 
-	context = build_get_context (bplugin, prog->work_dir, with_view, check_password);
+	context = build_get_context (bplugin, prog->work_dir, with_view);
 
 	build_set_command_in_context (context, prog);
 	if (!build_save_and_execute_command_in_context (context, err))
@@ -509,7 +510,7 @@ build_save_distclean_and_execute_command (BasicAutotoolsPlugin* bplugin, BuildPr
 	BuildConfiguration *config;
 	GList *vars;
 
-	context = build_get_context (bplugin, prog->work_dir, with_view, FALSE);
+	context = build_get_context (bplugin, prog->work_dir, with_view);
 	root_path = g_file_get_path (bplugin->project_root_dir);
 	same = strcmp (prog->work_dir, root_path) != 0;
 	g_free (root_path);
@@ -574,7 +575,7 @@ build_build_file_or_dir (BasicAutotoolsPlugin *plugin,
 	build_program_set_callback (prog, callback, user_data);
 	build_program_add_env_list (prog, vars);
 
-	context = build_save_and_execute_command (plugin, prog, TRUE, FALSE, err);
+	context = build_save_and_execute_command (plugin, prog, TRUE, err);
 	g_free (target);
 	g_object_unref (build_dir);
 
@@ -602,7 +603,7 @@ build_is_file_built (BasicAutotoolsPlugin *plugin, GFile *file,
 	{
 		return NULL;
 	}
-	
+
 	vars = build_configuration_get_variables (config);
 
 	build_dir = build_file_from_file (plugin, file, &target);
@@ -613,7 +614,7 @@ build_is_file_built (BasicAutotoolsPlugin *plugin, GFile *file,
 	build_program_set_callback (prog, callback, user_data);
 	build_program_add_env_list (prog, vars);
 
-	context = build_save_and_execute_command (plugin, prog, FALSE, FALSE, err);
+	context = build_save_and_execute_command (plugin, prog, FALSE, err);
 
 	g_free (target);
 	g_object_unref (build_dir);
@@ -643,7 +644,6 @@ build_install_dir (BasicAutotoolsPlugin *plugin, GFile *dir,
 {
 	BuildContext *context;
 	gchar* root = get_root_install_command(plugin);
-	gboolean use_root = FALSE;
 	GFile *build_dir;
 	BuildProgram *prog;
 	GString *command;
@@ -690,7 +690,6 @@ build_install_dir (BasicAutotoolsPlugin *plugin, GFile *dir,
 			}
 		}
 		g_string_append (command, first);
-		use_root = TRUE;
 	}
 	else
 	{
@@ -708,7 +707,7 @@ build_install_dir (BasicAutotoolsPlugin *plugin, GFile *dir,
 	build_program_set_callback (prog, callback, user_data);
 	build_program_add_env_list (prog, vars);
 
-	context = build_save_and_execute_command (plugin, prog, TRUE, use_root, err);
+	context = build_save_and_execute_command (plugin, prog, TRUE, err);
 
 	g_string_free (command, TRUE);
 	g_object_unref (build_dir);
@@ -720,8 +719,8 @@ build_install_dir (BasicAutotoolsPlugin *plugin, GFile *dir,
 
 
 BuildContext*
-build_clean_dir (BasicAutotoolsPlugin *plugin, GFile *file,
-				 GError **err)
+build_clean_dir (BasicAutotoolsPlugin *plugin, GFile *dir,
+                 GError **err)
 {
 	BuildContext *context = NULL;
 	BuildProgram *prog;
@@ -729,12 +728,12 @@ build_clean_dir (BasicAutotoolsPlugin *plugin, GFile *file,
 	BuildConfiguration *config;
 	GList *vars;
 
-	if (is_configured (plugin, file))
+	if (is_configured (plugin, dir))
 	{
 		config = build_configuration_list_get_selected (plugin->configurations);
 		vars = build_configuration_get_variables (config);
 
-		build_dir = build_file_from_file (plugin, file, NULL);
+		build_dir = build_file_from_file (plugin, dir, NULL);
 
 		prog = build_program_new_with_command (build_dir,
 		                                       "%s",
@@ -748,7 +747,33 @@ build_clean_dir (BasicAutotoolsPlugin *plugin, GFile *file,
 	return context;
 }
 
+BuildContext*
+build_check_dir (BasicAutotoolsPlugin *plugin, GFile *dir,
+                 IAnjutaBuilderCallback callback, gpointer user_data,
+				 GError **err)
+{
+	BuildContext *context = NULL;
+	BuildProgram *prog;
+	GFile *build_dir;
+	BuildConfiguration *config;
+	GList *vars;
 
+	config = build_configuration_list_get_selected (plugin->configurations);
+	vars = build_configuration_get_variables (config);
+
+	build_dir = build_file_from_file (plugin, dir, NULL);
+
+	prog = build_program_new_with_command (build_dir,
+	                                       "%s",
+	                                       CHOOSE_COMMAND (plugin, CHECK)),
+	build_program_set_callback (prog, callback, user_data);
+	build_program_add_env_list (prog, vars);
+
+	context = build_execute_command (plugin, prog, TRUE, err);
+	g_object_unref (build_dir);
+
+	return context;
+}
 
 static void
 build_remove_build_dir (GObject *sender,
@@ -800,7 +825,7 @@ build_tarball (BasicAutotoolsPlugin *plugin)
 	                                       CHOOSE_COMMAND (plugin, BUILD_TARBALL)),
 	build_program_add_env_list (prog, vars);
 
-	context = build_save_and_execute_command (plugin, prog, TRUE, FALSE, NULL);
+	context = build_save_and_execute_command (plugin, prog, TRUE, NULL);
 
 	return context;
 }
@@ -836,7 +861,7 @@ build_compile_file (BasicAutotoolsPlugin *plugin, GFile *file)
 
 		build_program_add_env_list (prog, vars);
 
-		context = build_save_and_execute_command (plugin, prog, TRUE, FALSE, NULL);
+		context = build_save_and_execute_command (plugin, prog, TRUE, NULL);
 		g_object_unref (object);
 	}
 	else
